## ---- include=FALSE------------------------------------------------------
library(icd)

## ----head----------------------------------------------------------------
head(icd9_map_cc)

## ----pts-----------------------------------------------------------------
pts <- data.frame(patient_id = c("1", "2", "3", "4", "4"),
                  icd_code = c("20084", "1742", "30410", "41514", "95893"), 
                  date = as.Date(c("2011-01-01", "2011-01-02", "2011-01-03", "2011-01-04", "2011-01-04")))

pts

## ----hcc-----------------------------------------------------------------
comorbid_hcc(pts)

